pub struct DocumentFileEncryptResult { /* private fields */ }Expand description
Result of file encryption (managed).
Produced by document_file_encrypt.
Implementations
Sourceimpl DocumentFileEncryptResult
impl DocumentFileEncryptResult
Sourcepub fn id(&self) -> &DocumentId
pub fn id(&self) -> &DocumentId
ID of the encrypted document
Sourcepub fn name(&self) -> Option<&DocumentName>
pub fn name(&self) -> Option<&DocumentName>
Name of the document
Sourcepub fn created(&self) -> &OffsetDateTime
pub fn created(&self) -> &OffsetDateTime
Date and time when the document was created
Sourcepub fn last_updated(&self) -> &OffsetDateTime
pub fn last_updated(&self) -> &OffsetDateTime
Date and time when the document was last updated
Sourcepub fn grants(&self) -> &[UserOrGroup]
pub fn grants(&self) -> &[UserOrGroup]
Users and groups the document was successfully encrypted to
Sourcepub fn access_errs(&self) -> &[DocAccessEditErr]
pub fn access_errs(&self) -> &[DocAccessEditErr]
Errors resulting from failure to encrypt to specific users/groups