DocumentFileEncryptUnmanagedResult

Struct DocumentFileEncryptUnmanagedResult 

pub struct DocumentFileEncryptUnmanagedResult { /* private fields */ }
Result of file encryption (unmanaged).

Produced by document_file_encrypt_unmanaged.

Implementations

Source

impl DocumentFileEncryptUnmanagedResult

pub fn id(&self) -> &DocumentId

ID of the encrypted document

pub fn encrypted_deks(&self) -> &[u8]

Bytes of EDEKs of users/groups that have been granted access

pub fn grants(&self) -> &[UserOrGroup]

Users and groups the document was successfully encrypted to

pub fn access_errs(&self) -> &[DocAccessEditErr]

Errors resulting from failure to encrypt to specific users/groups