pub struct DocumentFileEncryptUnmanagedResult { /* private fields */ }Expand description
Result of file encryption (unmanaged).
Produced by document_file_encrypt_unmanaged.
Implementations
Sourceimpl DocumentFileEncryptUnmanagedResult
impl DocumentFileEncryptUnmanagedResult
Sourcepub fn id(&self) -> &DocumentId
pub fn id(&self) -> &DocumentId
ID of the encrypted document
Sourcepub fn encrypted_deks(&self) -> &[u8] ⓘ
pub fn encrypted_deks(&self) -> &[u8] ⓘ
Bytes of EDEKs of users/groups that have been granted access
Sourcepub fn grants(&self) -> &[UserOrGroup]
pub fn grants(&self) -> &[UserOrGroup]
Users and groups the document was successfully encrypted to
Sourcepub fn access_errs(&self) -> &[DocAccessEditErr]
pub fn access_errs(&self) -> &[DocAccessEditErr]
Errors resulting from failure to encrypt to specific users/groups