pub struct DocumentEncryptOpts { /* private fields */ }Expand description
Parameters that can be provided when encrypting a new document.
Document IDs must be unique to the segment. If no ID is provided, one will be generated for it. If no name is provided, the document’s name will be left empty. Neither the document’s ID nor name will be encrypted.
Default values are provided with DocumentEncryptOpts::default().
Implementations
Sourceimpl DocumentEncryptOpts
impl DocumentEncryptOpts
Sourcepub fn new(
id: Option<DocumentId>,
name: Option<DocumentName>,
grants: EitherOrBoth<ExplicitGrant, PolicyGrant>,
) -> DocumentEncryptOpts
pub fn new( id: Option<DocumentId>, name: Option<DocumentName>, grants: EitherOrBoth<ExplicitGrant, PolicyGrant>, ) -> DocumentEncryptOpts
Constructs a new DocumentEncryptOpts.
Document encryption requires an ExplicitGrant, a PolicyGrant, or both. If only using one type
of grant, consider using with_explicit_grants
or with_policy_grants instead.
Arguments
id- ID to use for the document.name- Name to use for the document.grants- Grants that control who will have access to read and decrypt this document.
Sourcepub fn with_explicit_grants(
id: Option<DocumentId>,
name: Option<DocumentName>,
grant_to_author: bool,
grants: Vec<UserOrGroup>,
) -> DocumentEncryptOpts
pub fn with_explicit_grants( id: Option<DocumentId>, name: Option<DocumentName>, grant_to_author: bool, grants: Vec<UserOrGroup>, ) -> DocumentEncryptOpts
Constructs a new DocumentEncryptOpts with access explicitly granted to certain users and groups.
Arguments
id- ID to use for the document.name- Name to use for the document.grant_to_author-trueif the calling user should have access to decrypt the documentgrants- List of users and groups that should have access to read and decrypt this document
Sourcepub fn with_policy_grants(
id: Option<DocumentId>,
name: Option<DocumentName>,
policy: PolicyGrant,
) -> DocumentEncryptOpts
pub fn with_policy_grants( id: Option<DocumentId>, name: Option<DocumentName>, policy: PolicyGrant, ) -> DocumentEncryptOpts